@@ -15,7 +15,7 @@ use Filter::signatures;
 use feature 'signatures';
 no warnings 'experimental::signatures';
 
-our $VERSION = '0.42';
+our $VERSION = '0.43';
 
 =head1 NAME
 
@@ -140,31 +140,36 @@ provide a cookie jar in your user agent.
 =cut
 
 our @option_spec = (
-    'user-agent|U=s',
-    'referer=s',
-    'verbose|v',             # ignored
-    'quiet',                 # ignored
-    'buffer!',
-    'compression=s',
-    'cookie|b=s',
-    'load-cookies|c=s',
-    'post-data=s',
-    'post-file=s',
+    'auth-no-challenge',     # ignored
     'body-data=s',
     'body-file=s',
+    'buffer!',
+    'cache!',
+    'ca-directory=s',
+    'check-certificate!',
+    'certificate=s',
+    'compression=s',
     'content-disposition=s',
-    'auth-no-challenge',     # ignored
+    'cookie|b=s@',
+    'cookies!',              # ignored
+    'debug',                 # ignored
     'form|F=s@',
     'header|H=s@',
-    'method=s',
-    'max-time|m=s',
     'http-keep-alive!',
-    'cache!',
-    'http-user=s',
     'http-password=s',
-    'check-certificate!',
+    'http-user=s',
+    'load-cookies|c=s',
+    'method=s',
+    'no-verbose|nv',         # ignored
     'output-document|O=s',   # ignored
-    'debug',                 # ignored
+    'post-data=s',
+    'post-file=s',
+    'progress!',             # ignored
+    'quiet',                 # ignored
+    'referer=s',
+    'timeout|T=i',
+    'user-agent|U=s',
+    'verbose|v',             # ignored
 );
 
 sub new( $class, %options ) {
@@ -429,6 +434,8 @@ sub _build_request( $self, $uri, $options, %build_options ) {
             uri    => $uri,
             headers => \%headers,
             body   => $body,
+            maybe cert => $options->{certificate},
+            maybe capath => $options->{'ca-directory'},
             maybe credentials => $options->{ user },
             maybe output => $options->{ output },
             maybe timeout => $options->{ 'max-time' },
